@@ -8,6 +8,7 @@ class EdgeTypeLabels(Enum):
     generic = "Edge"
     table_to_column = "TableToColumn"
     column_to_column = "ColumnToColumn"
+    table_to_table = "TableToTable"
 
 
 class GenericEdgeMetadataV1(V1Mixin):
@@ -24,6 +25,15 @@ class TableToColumnMetadata(GenericEdgeMetadataV1):
     edge_attributes: TableToColumnAttributes = TableToColumnAttributes()
 
 
+class TableToTableAttributes(V1Mixin):
+    pass
+
+
+class TableToTableMetadata(GenericEdgeMetadataV1):
+    edge_type: Literal["TableToTable"]
+    edge_attributes: TableToColumnAttributes = TableToTableAttributes()
+
+
 class ColumnToColumnAttributes(V1Mixin):
     preserves_data_type: Optional[bool] = None
     preserves_nullable: Optional[bool] = None
